@@ -1,6 +1,7 @@
 
 # Authentication and Authorisation
 from functools import wraps
+from . import http
 
 def permit(test_func):
     '''Decorate a handler to control access'''
@@ -8,11 +9,15 @@ def permit(test_func):
         @wraps(view_func)
         def _wrapped_view(self, *args, **kwargs):
             if test_func(self, *args, **kwargs):
-                return view_func(*args, **kwargs)
-            return http.HttpResponseUnauthorized()
+                return view_func(self, *args, **kwargs)
+            return http.HttpResponseForbidden()
         return _wrapped_view
     return decorator
 
 permit_logged_in = permit(lambda self, request, *args, **kwargs: request.user.is_authenticated())
 permit_staff = permit(lambda self, request, *args, **kwargs: request.user.is_staff)
 
+def permit_groups(func, *groups):
+    def in_groups(request, *args):
+        return requets.user.groups.filter(name__in=args).exists()
+    return permit(lambda self, request, *args, **kwargs: in_groups(request, *groups))
